EXPORTS
	??0RUsbHostStack@@QAE@XZ @ 1 NONAME ; RUsbHostStack::RUsbHostStack(void)
	?Connect@RUsbHostStack@@QAEHXZ @ 2 NONAME ; int RUsbHostStack::Connect(void)
	?DisableDriverLoading@RUsbHostStack@@QAEXXZ @ 3 NONAME ; void RUsbHostStack::DisableDriverLoading(void)
	?EnableDriverLoading@RUsbHostStack@@QAEHXZ @ 4 NONAME ; int RUsbHostStack::EnableDriverLoading(void)
	?GetManufacturerStringDescriptor@RUsbHostStack@@QAEHIIAAV?$TBuf@$0IA@@@@Z @ 5 NONAME ; int RUsbHostStack::GetManufacturerStringDescriptor(unsigned int, unsigned int, class TBuf<128> &)
	?GetProductStringDescriptor@RUsbHostStack@@QAEHIIAAV?$TBuf@$0IA@@@@Z @ 6 NONAME ; int RUsbHostStack::GetProductStringDescriptor(unsigned int, unsigned int, class TBuf<128> &)
	?GetSupportedLanguages@RUsbHostStack@@QAEHIAAV?$RArray@I@@@Z @ 7 NONAME ; int RUsbHostStack::GetSupportedLanguages(unsigned int, class RArray<unsigned int> &)
	?NotifyDeviceEvent@RUsbHostStack@@QAEXAAVTRequestStatus@@AAVTDeviceEventInformation@@@Z @ 8 NONAME ; void RUsbHostStack::NotifyDeviceEvent(class TRequestStatus &, class TDeviceEventInformation &)
	?NotifyDeviceEventCancel@RUsbHostStack@@QAEXXZ @ 9 NONAME ; void RUsbHostStack::NotifyDeviceEventCancel(void)
	?NotifyDevmonEvent@RUsbHostStack@@QAEXAAVTRequestStatus@@AAH@Z @ 10 NONAME ; void RUsbHostStack::NotifyDevmonEvent(class TRequestStatus &, int &)
	?NotifyDevmonEventCancel@RUsbHostStack@@QAEXXZ @ 11 NONAME ; void RUsbHostStack::NotifyDevmonEventCancel(void)
	?Version@RUsbHostStack@@QBE?AVTVersion@@XZ @ 12 NONAME ; class TVersion RUsbHostStack::Version(void) const
	?__DbgAlloc@RUsbHostStack@@QAEHXZ @ 13 NONAME ; int RUsbHostStack::__DbgAlloc(void)
	?__DbgFailNext@RUsbHostStack@@QAEHH@Z @ 14 NONAME ; int RUsbHostStack::__DbgFailNext(int)
	?GetOtgDescriptor@RUsbHostStack@@QAEHIAAVTOtgDescriptor@@@Z @ 15 NONAME ; int RUsbHostStack::GetOtgDescriptor(unsigned int, class TOtgDescriptor &)

